function data = readSimData(fileprefix)
%Reads similarity data from SimilarityLearning format
%   DATA = READSIMDATA(FILEPREFIX) reads the data from the files 
%   FILEPREFIX.dat and FILEPREFIX.lbl to the structure DATA. 
%   
%   DATA is a 1x1 struct containing the following fields:
%     DATA.S    The nxn similarity matrix
%     DATA.lbl  The nx1 vector of labels corresponding to the objects in
%               the similarity matrix.
%
%   Example
%     %Reads 'mydataset.dat' and 'mydataset.lbl' from the current dir
%     data = readSimData('mydataset'); 
%

datfile = [fileprefix '.dat'];
lblfile = [fileprefix '.lbl'];

%READ THE .DAT FILE
[rows,cols] = textread(datfile,'%d %d',1);
sym = textread(datfile,'%s',1,'headerlines',1);
[r,c,simData] = textread(datfile,'%d %d %f','headerlines',2);

S = sparse(r+1,c+1,simData,rows,cols);
if strcmp(sym,'symmetric')
    S = S' + triu(S,1);
end

%READ THE .LBL FILE
y = textread(lblfile);

data.S = S;
data.lbl = y;
