function writeSimData(data,symflag,fileprefix)
%Writes similarity data to SimilarityLearning format
%   WRITESIMDATA(DATA,SYMFLAG,FILEPREFIX) writes the data stored in the
%   structure DATA to FILEPREFIX.dat and FILEPREFIX.lbl
%   SYMFLAG=1 indicates the data is symmetric, while SYMFLAG=0
%   indicates that it is not.
%   
%   DATA must be a 1x1 struct containing at least the following fields:
%     DATA.S    The nxn similarity matrix
%     DATA.lbl  The nx1 vector of labels corresponding to the objects in
%               the similarity matrix.
%
%   The data will be written to the following files:
%     OUTFILE.dat The similarity matrix.
%     OUTFILE.lbl The labels.
%   
%   Example
%     data.S = randn(10,10);
%     data.lbl = ceil(3*rand(10,1));
%     writeSimData(data,0,'testdata');
%

M = data.S;
vec = data.lbl;

datfile = [fileprefix '.dat'];
lblfile = [fileprefix '.lbl'];

%WRITE THE DATA
fid = fopen(datfile,'w');

fprintf(fid,'%i\t%i\n',size(M,1),size(M,2));

if symflag==1
  fprintf(fid,'symmetric\n');
  for i=1:size(M,1)
    for j=i:size(M,2)
      if M(i,j) ~= 0
        fprintf(fid,'%i %i\t%1.5f\n',i-1,j-1,M(i,j));
      end
    end
  end
else
  fprintf(fid,'asymmetric\n'); 
  for i=1:size(M,1)
    for j=1:size(M,2)
      if M(i,j) ~= 0
        fprintf(fid,'%i %i\t%1.5f\n',i-1,j-1,M(i,j));
      end
    end
  end
end

fclose(fid);


%WRITE THE LABELS
fid = fopen(lblfile,'w');

for i=1:length(vec)
    fprintf(fid,'%i\n',vec(i));
end

fclose(fid);
