function [lambda, gamma, estErr] = computeLambda(classMean, domainVector)
%computeLambda - optimize exponent in MaxEnt exponential distribution.
% Uses the Matlab built-in function fminsearch() to find the optimum value
% of lambda for a mean-constrained maximum entropy problem.
% USAGE
% [lambda, gamma, errorInLambda] = computeLambda(classMean, domainVector)
% classMean - mean constraint in MaxEnt problem.
% domainVector - vector of possible (discrete) values taken on by the
%     exponent. 
% lambda - value of the optimized exponent.
% gamma - values of normalization constant.
% estErr - estimation error.

% Written by Maya Gupta, Dept EE, University of Washington.
% Modified by Luca Cazzanti, APL-UW.


[lambda, estErr] = fminsearch(@optLambda, 0);
expValue = sum(exp(lambda * domainVector));
if expValue == 0
  lambda = -Inf;
  gamma = 1;
else
  gamma = 1/ sum(exp(lambda * domainVector)); % normalization factor
end

function theErr = optLambda(posLambda)
  elambdaVect = exp(posLambda*domainVector);
  sumELambdaVect = sum(elambdaVect);
  if sumELambdaVect == 0
    posLambda = -Inf; 
    theErr = 0;
    return
  end
    
 % normalize the pmf and then calc the mean:
  meanpmf = sum(domainVector.*(elambdaVect/sumELambdaVect));
  theErr = abs(meanpmf - classMean); % abs error to empirical mean

end % end optLambda

end % end computeLambda
