function regularizingParams = createRegularizedLambdaParamStruct( ...
  lambdaType, regLambda, regParam, neighborType, centroidType, ...
  nNeighbors, simDomain, classLabels)
%createRegularizingLambdaParamStruct - create structure for lambda-regularized local SDA.
% Creates a structure whose fields are necessary parameters for the
% lambda-regularized local SDA classifier. 
% USAGE
% paramStruct = createRegularizedLambdaParamStruct( ...
%    lambdaType, regLambda, regParam, neighborType, centroidType, ...
%    nNeighbors, simDomain, classLabels)
% lambdaType - either 'average' or 'global'
% regLambda - a C-by-C matrix of lambda parameters that regularize the
%     local SDA lambdas, where C is the number of classes.
% regParam - the regularization constant
% neighborType - either 'kPerClass' or 'kTotal'
% centroidType - only 'maxSumSim' has been tested
% nNeighbors - number of neighbors for local SDA
% simDomain - vector of possible similarity values
% classLabels - vector of numeric labels for the C classes
% paramStruct - the parameters structure, with fieldnames identical to the
%     input parameter names.
%
% See also classifyRegularizedLambdaLocalSda.

% Written by Luca Cazzanti, engineer.
% Applied Physics Laboratory, University of Washington, March 2009.
%$Id:$
%$DateTime:$
%$Author:$

regularizingParams.lambdaType = lambdaType;
regularizingParams.regLambda = regLambda;
regularizingParams.regParam = regParam;
regularizingParams.neighborType = neighborType;
regularizingParams.centroidType = centroidType;
regularizingParams.nNeighbors = nNeighbors;
regularizingParams.simDomain = simDomain;
regularizingParams.classLabels = classLabels;

return
