function centroidIdx = findCentroid(simMat, centroidType)
%findCentroid - find similarity-based centroid.
% This function is a wrapper which calls the appropriate centroid-specific
% functions. UIsers can enhance this function with other centroid
% definitions by writing their own centroid-specific function which is then
% called by this function.
%
% USAGE
% centroidIdx = findCentroid(simMat, centroidType)
% simMat: matrix of pairwise similarities.
% centroidType: string indicating the desired type of centroid. Allowed
%     types are: 'maxSumSim', 'mostPopular'.
% centroidIdx: row index into simMat denoting the centroid.
%

% Written by Luca Cazzanti, engineer.
% Applied Physics Laboratory, University of Washington, November 2006.
%$Id:$
%$DateTime:$
%$Author:$

switch centroidType
  case 'maxSumSim'
    centroidIdx = findCentroidMaxSumSim(simMat);
  case 'mostPopular'
    centroidIdx = findCentroidMostPopular(simMat); 
  otherwise
    error(['Centroid type ' centroidType ' not supported']);
end %switch

return